module.exports = defineTest({
	description: 'folds exponentiation operator when considering dead code'
});
